@@ -14,6 +14,7 @@ from SentiNet.PolarityType import PolarityType
 
 import re
 
+from AnnotatedSentence.Language import Language
 from AnnotatedSentence.ViewLayerType import ViewLayerType
 
 
@@ -40,6 +41,8 @@ class AnnotatedWord(Word):
     __slot: Slot
     __polarity: PolarityType
     __ccg: str
+    __posTag: str
+    __language: Language
 
     def __init__(self, word: str, layerType=None):
         """
@@ -62,6 +65,7 @@ class AnnotatedWord(Word):
         self.__slot = None
         self.__polarity = None
         self.__ccg = None
+        self.__posTag = None
         if layerType is None:
             splitLayers = re.compile("[{}]").split(word)
             for layer in splitLayers:
@@ -72,8 +76,9 @@ class AnnotatedWord(Word):
                     continue
                 layerType = layer[:layer.index("=")]
                 layerValue = layer[layer.index("=") + 1:]
-                if layerType == "turkish":
+                if layerType == "turkish" or layerType == "english" or layerType == "persian":
                     self.name = layerValue
+                    self.__language = AnnotatedWord.getLanguageFromString(layerType)
                 elif layerType == "morphologicalAnalysis":
                     self.__parse = MorphologicalParse(layerValue)
                 elif layerType == "metaMorphemes":
@@ -97,6 +102,8 @@ class AnnotatedWord(Word):
                     self.__universalDependency = UniversalDependencyRelation(int(values[0]), values[1])
                 elif layerType == "ccg":
                     self.__ccg = layerValue
+                elif layerType == "posTag":
+                    self.__posTag = layerValue
         elif isinstance(layerType, NamedEntityType):
             super().__init__(word)
             self.__namedEntityType = layerType
@@ -123,7 +130,13 @@ class AnnotatedWord(Word):
         str
             String form of the AnnotatedWord.
         """
-        result = "{turkish=" + self.name + "}"
+        result = ""
+        if self.__language == Language.TURKISH:
+            result = "{turkish=" + self.name + "}"
+        elif self.__language == Language.ENGLISH:
+            result = "{english=" + self.name + "}"
+        elif self.__language == Language.PERSIAN:
+            result = "{persian=" + self.name + "}"
         if self.__parse is not None:
             result = result + "{morphologicalAnalysis=" + self.__parse.__str__() + "}"
         if self.__metamorphicParse is not None:
@@ -147,6 +160,8 @@ class AnnotatedWord(Word):
                      self.__universalDependency.__str__() + "}"
         if self.__ccg is not None:
             result = result + "{ccg=" + self.__ccg + "}"
+        if self.__posTag is not None:
+            result = result + "{posTag=" + self.__posTag + "}"
         return result
 
     def getLayerInfo(self, viewLayerType: ViewLayerType) -> str:
@@ -195,6 +210,8 @@ class AnnotatedWord(Word):
                 return self.__universalDependency.to().__str__() + "$" + self.__universalDependency.__str__()
         elif viewLayerType == ViewLayerType.CCG:
             return self.__ccg
+        elif viewLayerType == ViewLayerType.POS_TAG:
+            return self.__posTag
         else:
             return None
 
@@ -459,6 +476,28 @@ class AnnotatedWord(Word):
         """
         self.__ccg = ccg
 
+    def getPosTag(self) -> str:
+        """
+        Returns the posTag layer of the word.
+
+        RETURNS
+        -------
+        str
+            Pos tag of the word.
+        """
+        return self.__posTag
+
+    def setPosTag(self, posTag: str):
+        """
+        Sets the posTag layer of the word.
+
+        PARAMETERS
+        ----------
+        posTag : str
+            New pos tag of the word.
+        """
+        self.__posTag = posTag
+
     def getUniversalDependency(self) -> UniversalDependencyRelation:
         """
         Returns the universal dependency layer of the word.
@@ -525,3 +564,36 @@ class AnnotatedWord(Word):
         if "'" in wordLowercase and gazetteer.contains(wordLowercase[:wordLowercase.index("'")]) and \
                 self.__parse.containsTag(MorphologicalTag.PROPERNOUN):
             self.setNamedEntityType(gazetteer.getName())
+
+    def getLanguage(self) -> Language:
+        """
+        Returns the language of the word.
+
+        RETURNS
+        ----------
+        The language of the word.
+        """
+        return self.__language
+
+    @staticmethod
+    def getLanguageFromString(languageString: str) -> Language:
+        """
+        Converts a language string to language.
+
+        PARAMETERS
+        ----------
+        languageString : str
+            String defining the language name.
+
+        RETURNS
+        ----------
+        Language corresponding to the languageString.
+        """
+        if languageString == "turkish" or languageString == "Turkish":
+            return Language.TURKISH
+        elif languageString == "english" or languageString == "English":
+            return Language.ENGLISH
+        elif languageString == "persian" or languageString == "Persian":
+            return Language.PERSIAN
+        else:
+            return Language.TURKISH
